@@ -13,8 +13,8 @@
   packageStartupMessage("**  - Dimension Reduction and Estimation Toolbox")
   packageStartupMessage("**")
   packageStartupMessage("** Version    : ",this.version,"       (",this.year,")",sep="")
-  packageStartupMessage("** Maintainer : Kisung You  (kyoustat@gmail.com)")
-  packageStartupMessage("** Website    : https://kyoustat.com/Rdimtools/")
+  packageStartupMessage("** Maintainer : Kisung You  (kisungyou@outlook.com)")
+  packageStartupMessage("** Website    : https://kisungyou.com/Rdimtools/")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions to the maintainer.")
   packageStartupMessage("** ------------------------------------------------------- **")
